.. image:: https://badge.waffle.io/BD2KGenomics/toil.svg?label=ready&title=Ready
   :target: https://waffle.io/BD2KGenomics/toil
   :alt: 'Stories in Ready'

Toil is a scalable, efficient, cross-platform pipeline management system,
written entirely in Python, and designed around the principles of functional
programming.

* Check the `website`_ for a description of Toil and its features.
* Full documentation for the latest stable release can be found at
  `Read the Docs`_.

.. _website: http://toil.ucsc-cgl.org/
.. _Read the Docs: http://toil.readthedocs.org/


.. image:: https://badges.gitter.im/bd2k-genomics-toil/Lobby.svg
   :alt: Join the chat at https://gitter.im/bd2k-genomics-toil/Lobby
   :target: https://gitter.im/bd2k-genomics-toil/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge